summaryrefslogtreecommitdiffstats
path: root/lib/kformula/spaceelement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kformula/spaceelement.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/spaceelement.h')
-rw-r--r--lib/kformula/spaceelement.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/lib/kformula/spaceelement.h b/lib/kformula/spaceelement.h
index 52a666d1..0f5db35d 100644
--- a/lib/kformula/spaceelement.h
+++ b/lib/kformula/spaceelement.h
@@ -22,8 +22,8 @@
#ifndef SPACEELEMENT_H
#define SPACEELEMENT_H
-#include <qfont.h>
-#include <qstring.h>
+#include <tqfont.h>
+#include <tqstring.h>
#include "basicelement.h"
@@ -48,7 +48,7 @@ class SpaceElement : public BasicElement {
SpaceElement operator=( const SpaceElement& ) { return *this; }
public:
- SpaceElement( SpaceWidth space = THIN, bool tab=false, BasicElement* parent = 0 );
+ SpaceElement( SpaceWidth space = THIN, bool tab=false, BasicElement* tqparent = 0 );
SpaceElement( const SpaceElement& );
virtual SpaceElement* clone() {
@@ -67,7 +67,7 @@ public:
* @returns the character that represents this element. Used for
* parsing a sequence.
*/
- virtual QChar getCharacter() const { return ' '; }
+ virtual TQChar getCharacter() const { return ' '; }
// drawing
//
@@ -78,7 +78,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -86,16 +86,16 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
* Moves the cursor away from the given child. The cursor is
@@ -105,9 +105,9 @@ public:
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
protected:
@@ -116,36 +116,36 @@ protected:
/**
* @returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "SPACE"; }
+ virtual TQString getTagName() const { return "SPACE"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
/**
* Reads our attributes from the MathML element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromMathMLDom(const QDomElement& element);
+ virtual bool readAttributesFromMathMLDom(const TQDomElement& element);
private:
- virtual QString getElementName() const { return "mspace"; }
- virtual void writeMathMLAttributes( QDomElement& element ) const ;
+ virtual TQString getElementName() const { return "mspace"; }
+ virtual void writeMathMLAttributes( TQDomElement& element ) const ;
/**
* Whether this space behaves like a tab.
@@ -86,16 +86,16 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/